OiRA

Help

1. Preparación
2. Implicación
3. Identificación + Evaluación
4. Plan de acción
5. Informe
6. Grado de cumplimentación 0%

# Personalizar la evaluación de riesgos para su organización

Para personalizar la evaluación de riesgos conforme a su organización, se le podrá preguntar lo siguiente:

- seleccionar o saltar situaciones relevantes o no para su actividad empresarial y marcar la casilla si es necesario
- enumerar varias unidades de negocios, sucursales o tiendas, etc. Estos riesgos relacionados se repetirán con cada nombre que introduzca.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More